@@ -15,10 +15,10 @@
 
 import os
 import re
-import sys
 import copy
 from blockdiag.utils import images, unquote, urlutil, uuid, XY
 from blockdiag.utils.compat import u
+from blockdiag.utils.logging import warning
 from blockdiag import noderenderer, plugins
 
 
@@ -92,7 +92,7 @@ class Base(object):
             self.style = value.lower()
         else:
             class_name = self.__class__.__name__
-            msg = "WARNING: unknown %s style: %s\n" % (class_name, value)
+            msg = "unknown %s style: %s" % (class_name, value)
             raise AttributeError(msg)
 
 
@@ -197,22 +197,20 @@ class DiagramNode(Element):
         if noderenderer.get(value):
             self.shape = value
         else:
-            msg = "WARNING: unknown node shape: %s\n" % value
+            msg = "unknown node shape: %s" % value
             raise AttributeError(msg)
 
     def set_icon(self, value):
         if urlutil.isurl(value) or os.path.isfile(value):
             self.icon = value
         else:
-            msg = u("WARNING: icon image not found: %s\n") % value
-            sys.stderr.write(msg)
+            warning("icon image not found: %s", value)
 
     def set_background(self, value):
         if urlutil.isurl(value) or os.path.isfile(value):
             self.background = value
         else:
-            msg = u("WARNING: background image not found: %s\n") % value
-            sys.stderr.write(msg)
+            warning("background image not found: %s", value)
 
     def set_stacked(self, _):
         self.stacked = True
@@ -222,7 +220,7 @@ class DiagramNode(Element):
         if value in ('horizontal', 'vertical'):
             self.label_orientation = value
         else:
-            msg = "WARNING: unknown label orientation: %s\n" % value
+            msg = "unknown label orientation: %s" % value
             raise AttributeError(msg)
 
     def to_desctable(self):
@@ -338,7 +336,7 @@ class NodeGroup(Element):
         if value in ('landscape', 'portrait'):
             self.orientation = value
         else:
-            msg = "WARNING: unknown diagram orientation: %s\n" % value
+            msg = "unknown diagram orientation: %s" % value
             raise AttributeError(msg)
 
     def set_shape(self, value):
@@ -346,7 +344,7 @@ class NodeGroup(Element):
         if value in ('box', 'line'):
             self.shape = value
         else:
-            msg = "WARNING: unknown group shape: %s\n" % value
+            msg = "unknown group shape: %s" % value
             raise AttributeError(msg)
 
 
@@ -471,7 +469,7 @@ class DiagramEdge(Base):
         elif value == '--':
             self.dir = 'none'
         else:
-            msg = "WARNING: unknown edge dir: %s\n" % value
+            msg = "unknown edge dir: %s" % value
             raise AttributeError(msg)
 
     def set_color(self, color):
@@ -494,7 +492,7 @@ class DiagramEdge(Base):
             self.dir = 'both'
             self.hstyle = value
         else:
-            msg = "WARNING: unknown edge hstyle: %s\n" % value
+            msg = "unknown edge hstyle: %s" % value
             raise AttributeError(msg)
 
     def set_folded(self, _):
@@ -569,13 +567,9 @@ class Diagram(NodeGroup):
         self.edge_layout = None
 
     def set_plugin(self, name, attrs):
-        try:
-            kwargs = dict([str(unquote(attr.name)), unquote(attr.value)]
-                          for attr in attrs)
-            plugins.load([name], diagram=self, **kwargs)
-        except:
-            msg = "WARNING: fail to load plugin: %s\n" % name
-            raise AttributeError(msg)
+        kwargs = dict([str(unquote(attr.name)), unquote(attr.value)]
+                      for attr in attrs)
+        plugins.load([name], diagram=self, **kwargs)
 
     def set_plugins(self, value):
         modules = [name.strip() for name in value.split(',')]
@@ -585,7 +579,7 @@ class Diagram(NodeGroup):
         if noderenderer.get(value):
             DiagramNode.set_default_shape(value)
         else:
-            msg = "WARNING: unknown node shape: %s\n" % value
+            msg = "unknown node shape: %s" % value
             raise AttributeError(msg)
 
     def set_default_label_orientation(self, value):
@@ -593,13 +587,11 @@ class Diagram(NodeGroup):
         if value in ('horizontal', 'vertical'):
             DiagramNode.label_orientation = value
         else:
-            msg = "WARNING: unknown label orientation: %s\n" % value
+            msg = "unknown label orientation: %s" % value
             raise AttributeError(msg)
 
     def set_default_text_color(self, color):
-        msg = u("WARNING: default_text_color is obsoleted; "
-                "use default_textcolor\n")
-        sys.stderr.write(msg)
+        warning("default_text_color is obsoleted; use default_textcolor")
         self.set_default_textcolor(color)
 
     def set_default_textcolor(self, color):
@@ -616,13 +608,11 @@ class Diagram(NodeGroup):
         if re.search('^(?:none|solid|dotted|dashed|\d+(,\d+)*)$', value, re.I):
             self._DiagramNode.set_default_style(value)
         else:
-            msg = "WARNING: unknown %s style: %s\n" % value
+            msg = "unknown node style: %s" % value
             raise AttributeError(msg)
 
     def set_default_line_color(self, color):
-        msg = u("WARNING: default_line_color is obsoleted; "
-                "use default_linecolor\n")
-        sys.stderr.write(msg)
+        warning("default_line_color is obsoleted; use default_linecolor")
         self.set_default_linecolor(color)
 
     def set_default_linecolor(self, color):
@@ -652,21 +642,19 @@ class Diagram(NodeGroup):
         if value in ('solid', 'blur', 'none'):
             self.shadow_style = value
         else:
-            msg = "WARNING: unknown shadow style: %s\n" % value
+            msg = "unknown shadow style: %s" % value
             raise AttributeError(msg)
 
     def set_edge_layout(self, value):
         value = value.lower()
         if value in ('normal', 'flowchart'):
-            msg = u("WARNING: edge_layout is very experimental feature!\n")
-            sys.stderr.write(msg)
+            warning("edge_layout is very experimental feature!")
 
             self.edge_layout = value
         else:
-            msg = "WARNING: unknown edge layout: %s\n" % value
+            msg = "unknown edge layout: %s" % value
             raise AttributeError(msg)
 
     def set_fontsize(self, value):
-        msg = u("WARNING: fontsize is obsoleted; use default_fontsize\n")
-        sys.stderr.write(msg)
+        warning("fontsize is obsoleted; use default_fontsize")
         self.set_default_fontsize(int(value))
