@@ -13,6 +13,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import os
 import re
 import base64
 from blockdiag.imagedraw import base as _base
@@ -22,7 +23,7 @@ from blockdiag.imagedraw.simplesvg import (
 )
 from blockdiag.imagedraw.utils import cached
 from blockdiag.imagedraw.utils.ellipse import endpoints as ellipse_endpoints
-from blockdiag.utils import urlutil, Box, XY, is_Pillow_available
+from blockdiag.utils import images, Box, XY, is_Pillow_available
 
 feGaussianBlur = svgclass('feGaussianBlur')
 
@@ -227,9 +228,17 @@ class SVGImageDrawElement(_base.ImageDraw):
         self.svg.addElement(pg)
 
     def image(self, box, url):
-        if not urlutil.isurl(url):
-            string = open(url, 'rb').read()
-            url = "data:;base64," + str(base64.b64encode(string))
+        ext = os.path.splitext(url)[1].lower()
+        if ext not in ('.jpg', '.png', '.gif'):
+            stream = None
+            try:
+                stream = images.open(url, mode='png')
+                url = "data:;base64," + str(base64.b64encode(stream.read()))
+            except IOError:
+                pass
+            finally:
+                if stream:
+                    stream.close()
 
         im = image(url, box.x1, box.y1, box.width, box.height)
         self.svg.addElement(im)
